@@ -9,13 +9,15 @@ import torch
 import torch.nn as nn
 from tensorflow.keras.layers import Dense
 from tensorflow.keras.models import Sequential
-from thingsvision.core.extraction import Extractor
 from thingsvision.utils.data import DataLoader, ImageDataset
+from thingsvision import get_extractor
+
 
 DATA_PATH = "./data"
 TEST_PATH = "./test_images"
 OUT_PATH = "./test"
 
+
 MODEL_AND_MODULE_NAMES = {
     # Torchvision models
     "vgg16": {
@@ -157,10 +159,9 @@ def iterate_through_all_model_combinations():
         clip = MODEL_AND_MODULE_NAMES[model_name].get('clip', False)
         yield extractor, dataset, batches, modules, model_name, clip
 
-
 def create_extractor_and_dataloader(model_name: str, pretrained: bool, source: str, kwargs: dict={}):
     """Iterate through models and create model, dataset and data loader."""
-    extractor = Extractor(
+    extractor = get_extractor(
         model_name=model_name, pretrained=pretrained, device=DEVICE, source=source, model_parameters=kwargs
     )
     dataset = ImageDataset(
